@@ -5,13 +5,15 @@ from flask import Flask
 from apispec.ext.marshmallow import MarshmallowPlugin, BasePlugin
 from apispec.ext.marshmallow.common import resolve_schema_cls
 
+from iba_install.core.ibox import get_ibox
 
 from infiniguard_api.api_server.config import DevelopmentConfig
 from flask_apispec import FlaskApiSpec
 
 from infiniguard_api.view.node_api import node_api, RebootResource
 from infiniguard_api.common import messages
-from infiniguard_api.lib.rest.common import handle_error, handle_error_malformed
+from infiniguard_api.lib.rest.common import handle_error, handle_error_malformed,\
+    build_error_model, build_error_message, build_paginated_response
 from infiniguard_api.lib.hw.threads import start_worker
 from infiniguard_api.lib.hw.tasks import vacuum, get_session, delete_running_tasks
 
@@ -114,6 +116,11 @@ from infiniguard_api.view.infinibox_api import (infinibox_api, InfiniboxCustomEv
                                                 InfinidatLdapResource,
                                                 InfinidatLdapsResource)
 from infiniguard_api.__version__ import __version__
+from distutils.version import LooseVersion
+import json
+from pathlib import Path
+from infi.caching import cached_function
+from http import HTTPStatus
 
 SCHEMAS = list()
 
@@ -159,6 +166,26 @@ def schema_name_resolver(schema):
     return name
 
 
+def get_local_version() -> LooseVersion:
+    fname = '/etc/infiniguard-release.json'
+    release = json.loads(Path(fname).read_text())
+    return LooseVersion(release['infiniguard'])
+
+
+@cached_function
+def assure_running_version_uptodate():
+    lst = get_ibox().api.get('/api/rest/integrations/infiniguard/dde_nodes?fields=dde_instance_version').get_result()
+    max_iguard_ver = max(LooseVersion(elt['dde_instance_version']) for elt in lst)
+    myver = get_local_version()
+    if myver < max_iguard_ver:
+        error = build_error_model(
+            error_message=build_error_message(
+                {'DDE Version Check': f'API is disabled because this DDE is running outdated '
+                 f'version {myver} while {max_iguard_ver} is expected.'}),
+            error_code='DDE_VERSION_OUTDATED')
+        return build_paginated_response(error=error).to_primitive(), HTTPStatus.CONFLICT
+
+
 def create_app(*args, **kwargs):
     # Only enable in case of PDF generation
     if os.environ.get('PDF_GEN'):
@@ -169,7 +196,6 @@ def create_app(*args, **kwargs):
         dde_prefix = ''
         info = {}
 
-
     app = Flask(__name__)
     app.config.from_object(DevelopmentConfig)
     app.config.update({
@@ -200,7 +226,10 @@ def create_app(*args, **kwargs):
         replication_api, url_prefix=dde_prefix + '/replication/')
     app.register_blueprint(node_api, url_prefix=dde_prefix + '/node/')
     app.register_blueprint(nas_api, url_prefix=dde_prefix + '/nas/')
-    #app.register_blueprint(vtl_api, url_prefix=dde_prefix+'/vtl/')
+    # app.register_blueprint(vtl_api, url_prefix=dde_prefix+'/vtl/')
+
+    app.before_request(assure_running_version_uptodate)
+
     if os.environ.get('PDF_GEN'):
         app.register_blueprint(infinibox_api, url_prefix='/api/rest/')
     docs = FlaskApiSpec(app)
