@@ -1,7 +1,7 @@
 from flask_apispec import use_kwargs, marshal_with, doc, MethodResource
 from flask import Blueprint
 from infiniguard_api.lib.logging import iguard_logging
-from infiniguard_api.model.base_schema import MessageSchema, ErrorResponseSchema
+from infiniguard_api.model.base_schema import EmptyResponseSchema, ErrorResponseSchema
 from infiniguard_api.model.node_schemas import NodeRebootSchema
 from infiniguard_api.controller.node import reboot
 from infiniguard_api.lib.rest.common import http_code
@@ -19,12 +19,12 @@ class RebootResource(MethodResource):
     """
     @ddoc
     @use_kwargs(NodeRebootSchema)
-    @marshal_with(MessageSchema(), http_code.OK, description="MessageSchema returned on success")
+    @marshal_with(EmptyResponseSchema, http_code.OK, description="EmptyResponseSchema returned on success")
     @marshal_with(ErrorResponseSchema, description="ErrorResponseSchema on failure")
     def post(self, **kwargs):
         """
         :Summary: Reboot the system
-        :Description: Reboot the system after specified time, with a minimum of 20s and a maximum of 10m.
+        :Description: Reboot the system with an optional wait time of 1s to 10m.
         """
         response, code = reboot(**kwargs)
         return response, code
